# Table des matières

- [Auteur(s)](#auteurs)
- [Travail à réaliser](#travail-à-réaliser)
- [Installation/Tutoriel](#installationtutoriel)
    - [Installation de docker](#installation-de-docker)
    - [Installation de Jenkins](#installation-de-jenkins)
    - [Configuration de base Jenkins et de GitLab](#configuration-de-base-jenkins-et-de-gitlab)
    - [Liaison de Jenkins et de GitLab](#liaison-de-jenkins-et-de-gitlab)
    - [Intégration de Jenkins dans Gitlab](#intégration-de-jenkins-dans-gitlab)
- [Technologies utilisées](#technologies-utilisées)
- [Sources](#sources)

## Auteur(s)

|Nom|Prénom|login|email|
|--|--|--|--|
| *LEFRANCOIS* | *Raphael*| *lr131160* | *raphael.lefrancois@etu.univ-lehavre.fr* |
| *QUESNEY* | *Jules*| *qj141460* | *jules.quesney@etu.univ-lehavre.fr* |
| *VIMBERT* | *Fabien*| *vf130233* | *fabien.vimbert@etu.univ-lehavre.fr* |


## Travail à réaliser

L'objectif de ce mini projet est de se familiariser avec **Docker** à travers un exemple utilisant **Jenkins** et **Git**.


Construisez un conteneur Docker permettant de faire des tests en continu sur une application de votre choix hébergée sur le Git local (de l'université).

Jenkins doit être dans le conteneur et être relié à la Forge de l'université.


*Le rendu* : page(s) web sur votre compte Forge réalisée en Markdown pour présenter votre travail (façon tutoriel). 


*groupe* : par 4 maximum

## Installation/Tutoriel

### Installation de docker

Dans le cas ou docker est déjà installer et que vous souhaitez le supprimer, effectuer la commande :
```shell
sudo apt-get remove docker docker-engine docker.io
```

Dans un premier temps, veuillez mettre a jour les packages présents
```shell
sudo apt-get update
```

Puis installer les packages suivant
```shell
sudo apt-get install \
apt-transport-https \
ca-certificates \
curl \
software-properties-common
```

Enfin, installer docker via la commande suivante
```shell
curl -fsSL https://dowload.docker.com./linux/ubuntu/gpg | sudo apt-key add -
```

Ajoutez ensuite le répertoire suivant
```shell
sudo add-apt-repository "deb [arch-amd64] hattps://dowload.docker.com/linux/ubuntu \
$(lsb_release -cs) 
stable"
```

Enfin, installez docker-ce
```shell
sudo apt-get docker-ce
```

Pour tester si docker fonctionne correctement, vous pouvez effectuer la commande suivante
```shell
sudo run hello-world
```
Si cette dernière commande fonctione, le terminal devrai vous renvoyer :
```shell
Hello from Docker:
This message shows that your installation appears to be working correctly.
```


### Installation de Jenkins

Dans un premier temps, on cherche une image ubuntu (TODO ???)
```shell
sudo docker search ubuntu
```

Ensuite on télécharge l'image de jenkins (TODO ???)
```shell
sudo docker pull jenkins
```

Il faut vérifier que le Dockerfile sois présent avant d'effectuer la commande suivante permetant de créer une image de jenkins
```shell
sudo docker build -t jenkinsinstall .
```

Pour verifier que l'image que l'on viens de créer existe, vous pouvez entrer la commande
```shell
sudo docker images
```


### Configuration de base Jenkins et de GitLab

Pour executer l'image de Jenkins, tapez la commande
```shell
sudo docker run -t -i jenkinsinstall
```

Suite a cette commande, vous aurez le controle d'un termimal a l'intérieur de l'image

A l'intérieur de ce nouveau terminal, tapez :
```shell
service jenkins start
```

Par la suite, vous devrai utiliser votre navigateur favori afin d'avoir accès au commande graphique
Pour cela, vous devais entrez votre IP ainsi qu'un port pour pouvoir avoir acces a l'interface graphique de jenkins

En tappant cette commande, vous trouverez votre IP a coté de l'interface "eth0"
```shell
ifconfig
```

Par défault, l'IP est 172.17.0.2 et le port est 8080

Sur votre navigateur, vous devez obtenir le résultat suivant :

![4](img/4_AccessJenkinsFromNav.png)

Sur votre terminal Jenkins, tapez :
```shell
cat /var/lib/jenkins/secrets/initialAdminPassword
```

Copier le résultat puis collez le sur le navigateur

Sur votre navigateur, vous devez obtenir le résultat suivant :

![6](img/6_InstallJenkinsPlug.png)

Selectionnez l'option "installer les plugins suggérés"

Après l'installation, vous devez obtenir le résultat suivant :

![8](img/8_InstallPluginSucess.png)

Cliquez sur "Continuer en tant qu'Administrateur", a notez que votre identifiant sera "admin" et le mot de passe sera le mot de passe de /var/lib/jenkins/secrets/initialAdminPassword

Cliquez sur "Sauvez et terminer"

Cliquez sur "Conmmencer à utiliser Jenkins"

Vous devez obtenir le résultat suivant :

![10](img/10_TableauDeBord.png)

Cliquez sur "Nouveau Item"

Cliquez sur "Créer un nouveau job"

Vous devez obtenir le résultat suivant :

![12](img/12_CreateProject.png)

Saisissez un nom et Cliquez sur "Construire un projet free-style" puis sur "OK"





### Liaison de Jenkins et de GitLab

Pour cette partie, nous partons du principe que vous avez acces a un projet que vous possedez.
Dans le cadre de notre tutoriel, Nous allons reprendre ce projet (JenkinsGit) Avec un fichier HelloWorld.java a tester

Copiez le lien de votre projet : 

![5](img/5_ProjectLink.png)

Sur l'interface graphique de jenkins au moment de la configuration d'un projet.
Allez sur "Gestion de code source" et cliquez sur "Git"
Puis collez le lien git sur "Repository URL"

![6](img/6_PasterProjectLink.png)

Plus bas dans le formulaire, dans la section "Build", selectionner l'option "Ajouter un script shell" puis ajoutez vos tests.
Dans notre cas (un simple test de compilation java) le script est

```shell
javac HelloWorld.java
java HelloWorld
```

Puis confirmer le formulaire

Allez ensuite sur Projet > Espace de travail > Lancer un build

### Intégration de Jenkins dans Gitlab

#### Plugin Requis 
    
-Jenkins GitLab Plugin
-Jenkins Git Plugin
-Jenkins GitLab Hook plugin
    
Premièrement, nous devons créer un utilisateur qui permettras a jenkins d'interagir avec l'api gitlab.
Cet utilisateur doit avoir les permissions admin sur le projet.
    
Ouvrir gitlab et aller dans "Setting"
    
/*Screen 1*/
    
Ensuite, cliquer sur "Access Token" et créer un "token jenkins API"
    
/*Screen 2*/
    
Sauvegarder et copier "API token".
    
#### Configurer le serveur Jenkins
    
Aller sur Jenkins et installer "Jenkins Gitlab Plugin" et "Jenkins Git Plugin".
    
Aller dans "Manage Jenkins -> Configure System" et descendre dans la section GitLab.
    
Ecrire l'URL du serveur GitLab et l'ajouter.
    
Puis remplir les champs obligatoires comme sur l'image ci-dessous.
/*Screen 3*/
    
Selectioner "API Token credential" et cliquer sur test, un message succés devrait s'afficher.
/*Screen 4*/
    
####  Créer et configurer un projet Jenkins 
    
Créer un nouveau projet et cliquer sur configurer.
    
Donnez lui un nom, selectionner "Discard old builds" et ecrire "3" pour “Max # of builds to keep“.
Pour le champs “GitLab connection” selectionner "predefined connection" qui a été crée avec le plugin GitLab.
Pour Gitlab Repository Name” ecrire “<group name>/<repository name>“.
    
/*Screen 5*/
    
Puis aller dans "Credentials –> System –> “Add domain”" et cliquer sur "Add credentials".
    
/*Screen 6*/
    
Puis ajouter votre id et mots de passe GitLab.
    
Ensuite sélectionner Git comme "Source Code Management" et remplire les champs comme sur l'image.
/*Screen 7*/
    
####  Build Triggers
Pour la partis build trigers vous pouvez faire comme sur l'image.
    
/*Screen 8*/
    
Et enfin nous devrions ajouter “Publish build status to GitLab commit” pour accéder à des feedbacks.
    
/*Screen 9*/
    
Pour l'integration aller sur votre projet GitLab -> Setting -> intégrations.
Ajouter votre lien Jenkins.
Vous pouvez maintenant faire un test de connection.
    
Malheuresement l'intégration n'est possible que pour un serveur non Local nous n'avons 
donc pas pu réaliser cette partie.
    
    
    
*TODO* continue

## Technologies utilisées

- [Docker](https://www.docker.com/)
- [Jenkins](https://jenkins.io/)
- [Gitlab](https://about.gitlab.com/)

## Sources

- https://www.swtestacademy.com/jenkins-gitlab-integration/